Crate brine_ed25519

Crate brine_ed25519 

Modules

hasher

Structs

Address
The address of a Solana account.

Functions

verify
Verify an ed25519 signature over a vectored message.
verify_prehashed
Verify an ed25519 signature using a precomputed challenge hash H(R || A || M). This is useful in cases where the challenge hash needs to be computed off-chain or pre-computed on-chain for efficiency reasons.
verify_with_hasher
Verify an ed25519 signature over a vectored message using the provided hash implementation. Most callers want verify; this is the escape hatch for custom Hasher implementations.

Type Aliases

Signature